===
API
===

direct_collocation.py
=====================

.. automodule:: opty.direct_collocation
   :members:
   :inherited-members:

parameter_identification.py
===========================

.. automodule:: opty.parameter_identification
   :members:
   :inherited-members:

utils.py
========

.. automodule:: opty.utils
   :members:
   :inherited-members:
